///////////////////////////////////////////////////////////////////////////////
/*!\file    example.c
\brief      Lines 68-79 are  commented and the output is the expected 
            one.*/
///////////////////////////////////////////////////////////////////////////////

///////////////////////////////////////////////////////////////////////////////
/*!\brief   Funktion zum Testen eines Parity Fehlers
\spezification  Diese Funktion prft, ob der Prfling einen Response schickt 
            auf den direkten Frame nach der Einleitung der Kommunikation bei
            verflschten und unverflschtem Identifier. Die Prfung wird bei 
            der Default-Spannung des Prflings durchgefhrt.
\param[in]  dut ist ein Pointer auf die Struktur vom Typ tDutData.
\param[out] response ist ein Feld mit Flags, welche anzeigen, ob der Slave 
            einen Response sendet
\sa         LINTests_TestErrorParity*/
///////////////////////////////////////////////////////////////////////////////
void _TestErrorParity3 (tDutData *dut, 
                       char *response)
{
    int i;                  // Zhlindex fr for-Schleife (verflscht und 
                            // unverflscht)
    int number_of_values;   // Anzahl gefundener Positionen
    int last_edge_index;    // Position des letzten Werts
    int value_index[100];   // Feld fr die Positionen
    double delay = 100;     // Pause
    double secperdiv;       // Zeit pro Einheit am Oszillograph
    double curve[CURVESIZE3];   // Kurvendaten vom Oszillograph
    
    // for-Schleife (fr verflschten und unverflschten Identifier)
    for (i = 0; i < 2; i++)
    {
        // Verarbeiten der Systemereignisse - Buttons und Grafik
        ProcessSystemEvents ();
        // Einleiten der Kommunikation
        _SendFrames (modulno_lin, controller_lin, dut, timeout, modulno_can,
                 controller_can, number_of_frames, *frame, *timeout_flag);
        // Aufnahme starten
        Oscilloscope_SelectState (OSCILLOSCOPE_STATE_RUN);
        Delay (0.5);
        // falls Fehlerfall, dies auch auf der LIN-Karte setzen
        if (i == 0)
            LIN_ErrorMode (MODULNO3, CONTROLLER_MASTER, LIN_PARITY_ERROR);
        // bergeben des Identifiers
        LIN_MScheduleTableSet (MODULNO3, CONTROLLER_MASTER, LIN_TABLE0,
                               LIN_SET_TIME_ON, dut->baudrate,
                               DEFAULT_SYNCHBREAK, DEFAULT_SYNCHDELIMITER,
                               DEFAULT_ARBITRATIONDELAY, 1,
                               &dut->frames[DIRECT_FRAME].identifier, &delay);
        // falls Fehlerfall, dies auch auf der LIN-Karte setzen
        if (i == 0)
            LIN_ErrorMode (MODULNO3, CONTROLLER_MASTER, LIN_NO_ERROR);
        // Starten des Senden des (un-)verflschtem Identifiers
        LIN_MScheduleStart (MODULNO3, CONTROLLER_MASTER, LIN_TABLE0);
        Delay (0.025);
        // Lschen der Sendetabelle
        LIN_MScheduleTableDelete (MODULNO3, CONTROLLER_MASTER, LIN_TABLE0);
        
        // Holen der Aufnahme
        Oscilloscope_GetSingleAquisitionSequence (OSCILLOSCOPE_CHANNEL_1, 
                                                  curve, CURVESIZE3);
        // Suchen der Flanken
        number_of_values = 100;
        _FindEdges (curve, CURVESIZE3, value_index, &number_of_values, 
                    dut->voltage / 2, dut->voltage * 0.05);
        // Merken der Position der letzten Flanke
        last_edge_index = value_index[number_of_values - 1];
    
//      // Holen des anderen Kanals
//      Oscilloscope_GetCurve (OSCILLOSCOPE_CHANNEL_2, curve, CURVESIZE3);
//      // Suchen der Flanken
//      number_of_values = 100;
//      _FindEdges (curve, CURVESIZE3, value_index, &number_of_values, 1, 0.05);
//  
//      // falls Flanken nachdem Ende des Header empfangen wurden, hat der
//      // Slave den zugehrigen Response gesendet
//      if (last_edge_index > value_index[number_of_values - 1])
//          response[i] = TRUE;
//      else
//          response[i] = FALSE;
    }
}// _TestErrorParity3



///////////////////////////////////////////////////////////////////////////////
/*!\brief   Funktion zum Testen der Reaktion eines Slave bei einem 
            Checksummen-Fehler
\spezification  Diese Funktion baut eine Kommunikation mit einem Slave ber 
            eine indirekte Anfrage mit einem Frame auf. Danach wird mit Hilfe 
            des zugehrigen Identifiers die Antwort des Slave abgefragt. Bei 
            der Anfrage durch die LIN-Karte wird einmal ein Checksummen-Fehler
            eingebaut um zu sehen, ob der Slave dann auf den folgenden 
            Identifier nicht antwortet, d.h. er die Anfrage verworfen hat.
\param[in]  dut ist ein Pointer auf die Struktur vom Typ tDutData.
\param[out] response ist ein Feld mit Flags, welche anzeigen, ob der Slave 
            einen Response gesendet hat
\sa         LINTests_TestErrorChecksum*/
///////////////////////////////////////////////////////////////////////////////
void _TestErrorChecksumSlave3 (tDutData *dut, 
                              char *response)
{
    // Einleiten der Kommunikation
    _SendFrames (modulno_lin, controller_lin, dut, timeout, modulno_can,
                 controller_can, number_of_frames, *frame, *timeout_flag);
}// _TestErrorChecksumSlave3



///////////////////////////////////////////////////////////////////////////////
/*!\brief   Funktion zum Testen der Reaktion eines Slave bei einem 
            Checksummen-Fehler
\spezification  Diese Funktion baut eine Kommunikation mit einem Slave ber 
            eine indirekte Anfrage mit einem Frame auf. Danach wird mit Hilfe 
            des zugehrigen Identifiers die Antwort des Slave abgefragt. Bei 
            der Anfrage durch die LIN-Karte wird einmal ein Checksummen-Fehler
            eingebaut um zu sehen, ob der Slave dann auf den folgenden 
            Identifier nicht antwortet, d.h. er die Anfrage verworfen hat.
\param[in]  dut ist ein Pointer auf die Struktur vom Typ tDutData.
\param[out] response ist ein Feld mit Flags, welche anzeigen, ob der Slave 
            einen Response gesendet hat
\sa         LINTests_TestErrorDataLength*/
///////////////////////////////////////////////////////////////////////////////
void _TestErrorDataLengthSlave3 (tDutData *dut, 
                                char *response)
{
    // Einleiten der Kommunikation
    _SendFrames (modulno_lin, controller_lin, dut, timeout, modulno_can,
                 controller_can, number_of_frames, *frame, *timeout_flag);
}// _TestErrorDataLengthSlave3



